@@ -1,7 +1,7 @@
 package App::ListDebianReleases;
 
-our $DATE = '2014-08-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2014-12-29'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,7 @@ App::ListDebianReleases - List Debian releases
 
 =head1 VERSION
 
-This document describes version 0.02 of App::ListDebianReleases (from Perl distribution App-ListDebianReleases), released on 2014-08-21.
+This document describes version 0.03 of App::ListDebianReleases (from Perl distribution App-ListDebianReleases), released on 2015-12-29.
 
 =head1 FUNCTIONS
 
@@ -101,11 +101,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
